@@ -18,7 +18,7 @@ class BertSTEM:
 
         self._model = transformers.BertModel.from_pretrained(self.model_name)
 
-        self._tokenizer = transformers.BertTokenizerFast.from_pretrained(self.model_name,
+        self._tokenizer = transformers.BertTokenizerFast.from_pretrained("dccuchile/bert-base-spanish-wwm-uncased",
                                                                          do_lower_case = True,
                                                                          add_special_tokens = False)
 
@@ -30,7 +30,7 @@ class BertSTEM:
         
         model = transformers.BertForPreTraining.from_pretrained(checkpoint)
         
-        tokenizer = transformers.BertTokenizerFast.from_pretrained(checkpoint,
+        tokenizer = transformers.BertTokenizerFast.from_pretrained("dccuchile/bert-base-spanish-wwm-uncased",
                                                                    do_lower_case = True,
                                                                    add_special_tokens = False)
 
